@@ -146,11 +146,9 @@ class Simulation:
         normalizedDictionary = np.zeros_like(dictionary)
         for i in range(dictionaryShape[0]):
             normalizedDictionary[i,:] = dictionary[i,:]/dictionaryNorm[i]
-        (u,s,v) = np.linalg.svd(normalizedDictionary)
+        (u,s,v) = np.linalg.svd(normalizedDictionary, full_matrices=False)
         vt = np.transpose(v)
         self.truncationMatrix = vt[:,0:truncationNumber]
-        print(np.shape(normalizedDictionary))
-        print(np.shape(self.truncationMatrix))
         self.truncatedResults = np.matmul(normalizedDictionary,self.truncationMatrix).transpose()
 
     def Export(self, filename, force=False, includeFullResults=True, includeSVDResults=True):
